@@ -2,7 +2,7 @@ import numpy as np
 import os.path
 import matplotlib._pylab_helpers
 from matplotlib.backends.backend_pdf import PdfPages
-import time
+from time import time
 from pathlib import Path
 
 def is_number(variableValue,variableName,**kwargs):
@@ -39,21 +39,21 @@ def is_number(variableValue,variableName,**kwargs):
 
 def save_figures(destination,baseFileName,params,returnPath=False,**kwargs):
 	fileType = kwargs.get("fileType","png")
-    assert type(fileType)==str,"fileType must be a string."
-    fileType = fileType.lower()
+	assert type(fileType)==str,"fileType must be a string."
+	fileType = fileType.lower()
 	assert fileType in ["eps", "pdf", "pgf", "png", "ps", "raw", "rgba", "svg", "svgz"],\
 		"fileType must be one of the supported formats: eps, pdf, pgf, png, ps, raw, rgba, svg, svgz"
 
 	defaultSubFolderName = time.strftime("%Y_%m_%d_%H%M%S")
 	subFolderName = kwargs.get("subFolderName",defaultSubFolderName)
 
-    destination = Path(destination)
+	destination = Path(destination)
 	filePath = destination / subFolderName
 
-    assert destination.exist() and destination.is_dir(), "destination either does not exist or is not a directory."
-    assert type(subFolderName) == str, \
+	assert destination.exist() and destination.is_dir(), "destination either does not exist or is not a directory."
+	assert type(subFolderName) == str, \
 		"subFolderName must be a string. Currently subFolderName is '%s' with type %s." % (str(subFolderName),str(type(subFolderName)))
-    filePath.mkdir(exist_ok=True) # Create path if it doesn't already exist.
+	filePath.mkdir(exist_ok=True) # Create path if it doesn't already exist.
 
 	assert type(baseFileName) == str, \
 		"baseFileName must be a string. Currently baseFileName is '%s' with type %s." % (str(baseFileName),str(type(baseFileName)))
@@ -78,7 +78,7 @@ def save_figures(destination,baseFileName,params,returnPath=False,**kwargs):
 	while (filePath/fileName).exists():
 		i += 1
 		fileName = f"{baseFileName}_{i:0>2d}-01.{fileType}"
-    uniqueBase,_ = fileName.rsplit("-",1)
+	uniqueBase,_ = fileName.rsplit("-",1)
 
 	newFilePaths = []
 	for i in range(len(figs)):
@@ -87,8 +87,8 @@ def save_figures(destination,baseFileName,params,returnPath=False,**kwargs):
 		figs[i].savefig(newFilePath)
 
 	# Save notes file
-    YYYY,MM,DD,time = defaultSubFolderName.split("_")
-    hh,mm,ss = [time[i:i+2] for i in range(0,len(time),2)]
+	YYYY,MM,DD,time = defaultSubFolderName.split("_")
+	hh,mm,ss = [time[i:i+2] for i in range(0,len(time),2)]
 
 	if saveAsMD==False:
 		if (filePath/"notes.txt").exists():
@@ -98,12 +98,12 @@ def save_figures(destination,baseFileName,params,returnPath=False,**kwargs):
 			notesDocument = (filePath/"notes.txt").open('w')
 			notesDocument.write(f'[Created on {YYYY}/{MM}/{DD} at {hh}:{mm}.{ss} PST] \n\n')
 
-        paramString = f"{'#'*30}\n{'#'*11} Notes {'#'*12}\n{'#'*30}\n\n"
-        paramString += f"\t{addNotes}\n\n"
-        paramString += f"{'#'*30}\n{'#'*9} Parameters {'#'*9}\n{'#'*30}\n\n"
-        for key in params.keys():
-        	paramString += f"\t{key} : {str(params[key])}\n"
-        paramString += f"\n{'#'*30}\n\n"
+		paramString = f"{'#'*30}\n{'#'*11} Notes {'#'*12}\n{'#'*30}\n\n"
+		paramString += f"\t{addNotes}\n\n"
+		paramString += f"{'#'*30}\n{'#'*9} Parameters {'#'*9}\n{'#'*30}\n\n"
+		for key in params.keys():
+			paramString += f"\t{key} : {str(params[key])}\n"
+		paramString += f"\n{'#'*30}\n\n"
 		notesDocument.write(paramString)
 
 	else: # saveAsMD==True
@@ -112,14 +112,14 @@ def save_figures(destination,baseFileName,params,returnPath=False,**kwargs):
 			notesDocument.write(f'\n\n# Appended on {YYYY}/{MM}/{DD} at {hh}:{mm}.{ss} PST. \n\n')
 		else: # new folder, no README available
 			notesDocument = (filePath/"README.md").open('w')
-            notesDocument.write(f'\n\n# README.md for Figures Created on {YYYY}/{MM}/{DD} at {hh}:{mm}.{ss} PST. \n\n')
+			notesDocument.write(f'\n\n# README.md for Figures Created on {YYYY}/{MM}/{DD} at {hh}:{mm}.{ss} PST. \n\n')
 
-        paramString = f"## Notes\n\n{addNotes}\n\n"
-        paramString += "## Parameters \n\n```py\nparams = {\n"
-        for key in params.keys():
-        	paramString += f"\t'{key}' : '{str(params[key])}',\n"
-        paramString = paramString[:-2] # removing last ',\n'
-        paramString += "\n}\n```\n\n"
+		paramString = f"## Notes\n\n{addNotes}\n\n"
+		paramString += "## Parameters \n\n```py\nparams = {\n"
+		for key in params.keys():
+			paramString += f"\t'{key}' : '{str(params[key])}',\n"
+		paramString = paramString[:-2] # removing last ',\n'
+		paramString += "\n}\n```\n\n"
 		notesDocument.write(paramString)
 
 		notesDocument.write("## Figures\n\n")
